@@ -51,7 +51,7 @@
 
 /* Use the posix directory for the names. If people want a time based on posix or
  * right time, they can prepend that manually in the entry */
-#define ZONEINFO_DIR "/usr/share/zoneinfo/posix/"
+#define ZONEINFO_DIR "/usr/share/zoneinfo/"
 
 
 
@@ -457,9 +457,9 @@ clock_plugin_button_press_event (GtkWidget      *widget,
                && !panel_str_is_empty (plugin->command))
         {
           /* launch command */
-          if (!xfce_spawn_command_line_on_screen (gtk_widget_get_screen (widget),
-                                                  plugin->command, FALSE,
-                                                  FALSE, &error))
+          if (!xfce_spawn_command_line (gtk_widget_get_screen (widget),
+                                        plugin->command, FALSE,
+                                        FALSE, TRUE, &error))
             {
               xfce_dialog_show_error (NULL, error,
                                       _("Failed to execute clock command"));
@@ -948,9 +948,9 @@ clock_plugin_configure_run_config_tool (GtkWidget   *button,
 
   panel_return_if_fail (XFCE_IS_CLOCK_PLUGIN (plugin));
 
-  if (!xfce_spawn_command_line_on_screen (gtk_widget_get_screen (button),
-                                          plugin->time_config_tool,
-                                          FALSE, FALSE, &error))
+  if (!xfce_spawn_command_line (gtk_widget_get_screen (button),
+                                plugin->time_config_tool,
+                                FALSE, FALSE, TRUE, &error))
     {
       xfce_dialog_show_error (NULL, error, _("Failed to execute command \"%s\"."), plugin->time_config_tool);
       g_error_free (error);
@@ -971,6 +971,9 @@ clock_plugin_configure_zoneinfo_model_insert (GtkListStore *store,
 
   panel_return_if_fail (GTK_IS_LIST_STORE (store));
 
+  if (g_str_has_suffix (parent, "posix") || g_str_has_suffix (parent, "right"))
+    return;
+
   dir = g_dir_open (parent, 0, NULL);
   if (dir == NULL)
     return;
